/* gInfo - Copyright (C) 2004 bakunin - Andrea Marchesini 
 *                                      <bakunin@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#else
# error Use configure; make; make install
#endif

#include <editor.h>

GtkWidget *highlight_normal;
GtkWidget *highlight_xml;

int
graphic_create_window (void)
{
  GtkWidget *vbox;
  GtkWidget *notebook;
  GtkWidget *label;

  GtkWidget *menubar;
  GtkWidget *image;
  GtkWidget *sep;

  GtkWidget *highlight;
  GtkWidget *highlight_menu;
  GSList *highlight_group = NULL;
  GtkWidget *file;
  GtkWidget *file_menu;
  GtkWidget *file_item;
  GtkWidget *edit;
  GtkWidget *edit_menu;
  GtkWidget *edit_item;
  GtkWidget *tools;
  GtkWidget *tools_menu;
  GtkWidget *tools_item;

  GtkWidget *editor;
  GtkWidget *viewer;
  GtkWidget *info;
  GtkWidget *tips;

  char buf[1024];

  snprintf (buf, 1024, "%s %s - XML Module Editor", NAME, VERSION);

  editorwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (editorwin), buf);
  gtk_widget_set_size_request (editorwin, 640, 480);

  g_signal_connect ((gpointer) editorwin, "delete_event",
		    G_CALLBACK (graphic_quit), NULL);

  vbox = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox);
  gtk_container_add (GTK_CONTAINER (editorwin), vbox);

  menubar = gtk_menu_bar_new ();
  gtk_widget_show (menubar);
  gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, TRUE, 0);

  file = gtk_menu_item_new_with_mnemonic ("_File");
  gtk_widget_show (file);
  gtk_container_add (GTK_CONTAINER (menubar), file);

  file_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (file), file_menu);

  file_item = gtk_image_menu_item_new_with_mnemonic ("_New");
  gtk_widget_show (file_item);
  gtk_container_add (GTK_CONTAINER (file_menu), file_item);

  g_signal_connect ((gpointer) file_item, "activate", G_CALLBACK (editor_new),
		    NULL);

  image = gtk_image_new_from_stock ("gtk-new", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (file_item), image);

  file_item = gtk_image_menu_item_new_with_mnemonic ("_Open");
  gtk_widget_show (file_item);
  gtk_container_add (GTK_CONTAINER (file_menu), file_item);

  g_signal_connect ((gpointer) file_item, "activate",
		    G_CALLBACK (editor_open), NULL);

  image = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (file_item), image);

  sep = gtk_separator_menu_item_new ();
  gtk_widget_show (sep);
  gtk_container_add (GTK_CONTAINER (file_menu), sep);

  editor_save_item = gtk_image_menu_item_new_with_mnemonic ("_Save");
  gtk_widget_show (editor_save_item);
  gtk_container_add (GTK_CONTAINER (file_menu), editor_save_item);

  g_signal_connect ((gpointer) editor_save_item, "activate",
		    G_CALLBACK (editor_save), NULL);

  image = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (editor_save_item),
				 image);

  file_item = gtk_image_menu_item_new_with_mnemonic ("Save _As");
  gtk_widget_show (file_item);
  gtk_container_add (GTK_CONTAINER (file_menu), file_item);

  g_signal_connect ((gpointer) file_item, "activate",
		    G_CALLBACK (editor_save_as_m), NULL);

  image = gtk_image_new_from_stock ("gtk-save-as", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (file_item), image);

  sep = gtk_separator_menu_item_new ();
  gtk_widget_show (sep);
  gtk_container_add (GTK_CONTAINER (file_menu), sep);

  file_item = gtk_image_menu_item_new_with_mnemonic ("_Preferences");
  gtk_widget_show (file_item);
  gtk_container_add (GTK_CONTAINER (file_menu), file_item);

  image = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (file_item), image);

  g_signal_connect ((gpointer) file_item, "activate",
		    G_CALLBACK (preferences_create), NULL);

  sep = gtk_separator_menu_item_new ();
  gtk_widget_show (sep);
  gtk_container_add (GTK_CONTAINER (file_menu), sep);

  file_item = gtk_image_menu_item_new_with_mnemonic ("_Quit");
  gtk_widget_show (file_item);
  gtk_container_add (GTK_CONTAINER (file_menu), file_item);

  image = gtk_image_new_from_stock ("gtk-quit", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (file_item), image);

  g_signal_connect ((gpointer) file_item, "activate",
		    G_CALLBACK (graphic_quit), NULL);

  edit = gtk_menu_item_new_with_mnemonic ("_Edit");
  gtk_widget_show (edit);
  gtk_container_add (GTK_CONTAINER (menubar), edit);

  edit_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (edit), edit_menu);

  editor_undo_item = gtk_image_menu_item_new_with_mnemonic ("_Undo");
  gtk_widget_show (editor_undo_item);
  gtk_widget_set_sensitive (editor_undo_item, FALSE);
  gtk_container_add (GTK_CONTAINER (edit_menu), editor_undo_item);

  g_signal_connect ((gpointer) editor_undo_item, "activate",
		    G_CALLBACK (editor_undo), NULL);

  image = gtk_image_new_from_stock ("gtk-undo", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (editor_undo_item),
				 image);

  editor_redo_item = gtk_image_menu_item_new_with_mnemonic ("_Redo");
  gtk_widget_show (editor_redo_item);
  gtk_widget_set_sensitive (editor_redo_item, FALSE);
  gtk_container_add (GTK_CONTAINER (edit_menu), editor_redo_item);

  g_signal_connect ((gpointer) editor_redo_item, "activate",
		    G_CALLBACK (editor_redo), NULL);

  image = gtk_image_new_from_stock ("gtk-redo", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (editor_redo_item),
				 image);

  sep = gtk_separator_menu_item_new ();
  gtk_widget_show (sep);
  gtk_container_add (GTK_CONTAINER (edit_menu), sep);

  edit_item = gtk_image_menu_item_new_with_mnemonic ("Cu_t");
  gtk_widget_show (edit_item);
  gtk_container_add (GTK_CONTAINER (edit_menu), edit_item);

  g_signal_connect ((gpointer) edit_item, "activate", G_CALLBACK (editor_cut),
		    NULL);

  image = gtk_image_new_from_stock ("gtk-cut", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (edit_item), image);

  edit_item = gtk_image_menu_item_new_with_mnemonic ("_Copy");
  gtk_widget_show (edit_item);
  gtk_container_add (GTK_CONTAINER (edit_menu), edit_item);

  g_signal_connect ((gpointer) edit_item, "activate",
		    G_CALLBACK (editor_copy), NULL);

  image = gtk_image_new_from_stock ("gtk-copy", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (edit_item), image);

  edit_item = gtk_image_menu_item_new_with_mnemonic ("_Paste");
  gtk_widget_show (edit_item);
  gtk_container_add (GTK_CONTAINER (edit_menu), edit_item);

  image = gtk_image_new_from_stock ("gtk-paste", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (edit_item), image);

  g_signal_connect ((gpointer) edit_item, "activate",
		    G_CALLBACK (editor_paste), NULL);

  edit_item = gtk_image_menu_item_new_with_mnemonic ("_Delete");
  gtk_widget_show (edit_item);
  gtk_container_add (GTK_CONTAINER (edit_menu), edit_item);

  image = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (edit_item), image);

  g_signal_connect ((gpointer) edit_item, "activate",
		    G_CALLBACK (editor_delete), NULL);

  sep = gtk_separator_menu_item_new ();
  gtk_widget_show (sep);
  gtk_container_add (GTK_CONTAINER (edit_menu), sep);

  edit_item = gtk_image_menu_item_new_with_mnemonic ("Select _All");
  gtk_widget_show (edit_item);
  gtk_container_add (GTK_CONTAINER (edit_menu), edit_item);

  image = gtk_image_new_from_stock ("gtk-paste", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (edit_item), image);

  g_signal_connect ((gpointer) edit_item, "activate",
		    G_CALLBACK (editor_select_all), NULL);

  highlight = gtk_menu_item_new_with_mnemonic ("_Highlight");
  gtk_widget_show (highlight);
  gtk_container_add (GTK_CONTAINER (menubar), highlight);

  highlight_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (highlight), highlight_menu);

  highlight_normal =
    gtk_radio_menu_item_new_with_mnemonic (highlight_group, "_Normal");
  gtk_widget_show (highlight_normal);
  gtk_container_add (GTK_CONTAINER (highlight_menu), highlight_normal);

  highlight_group =
    gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (highlight_normal));

  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (highlight_normal),
				  FALSE);

  g_signal_connect ((gpointer) highlight_normal, "activate",
		    G_CALLBACK (editor_set_lang), NULL);

  highlight_xml =
    gtk_radio_menu_item_new_with_mnemonic (highlight_group, "_XML");
  gtk_widget_show (highlight_xml);
  gtk_container_add (GTK_CONTAINER (highlight_menu), highlight_xml);

  highlight_group =
    gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (highlight_xml));

  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (highlight_xml), TRUE);

  g_signal_connect ((gpointer) highlight_xml, "activate",
		    G_CALLBACK (editor_set_lang), "XML");

  tools = gtk_menu_item_new_with_mnemonic ("_Tools");
  gtk_widget_show (tools);
  gtk_container_add (GTK_CONTAINER (menubar), tools);

  tools_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (tools), tools_menu);

  tools_item = gtk_menu_item_new_with_mnemonic ("_Word Count");
  gtk_widget_show (tools_item);
  gtk_container_add (GTK_CONTAINER (tools_menu), tools_item);

  g_signal_connect ((gpointer) tools_item, "activate",
		    G_CALLBACK (tools_wordcount), NULL);

  tools_item = gtk_menu_item_new_with_mnemonic ("_Tags List");
  gtk_widget_show (tools_item);
  gtk_container_add (GTK_CONTAINER (tools_menu), tools_item);

  g_signal_connect ((gpointer) tools_item, "activate",
		    G_CALLBACK (tools_tagslist), NULL);

  notebook = gtk_notebook_new ();
  gtk_widget_show (notebook);
  gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_LEFT);

  editor = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (editor);
  gtk_container_add (GTK_CONTAINER (notebook), editor);

  label = gtk_label_new ("Editor");
  gtk_widget_show (label);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK
							 (notebook), 0),
			      label);

  if (editor_notebook (editor))
    return 1;

  info = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (info);
  gtk_container_add (GTK_CONTAINER (notebook), info);

  label = gtk_label_new ("Info");
  gtk_widget_show (label);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK
							 (notebook), 1),
			      label);

  if (parser_notebook (info))
    return 1;

  viewer = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (viewer);
  gtk_container_add (GTK_CONTAINER (notebook), viewer);

  label = gtk_label_new ("Viewer");
  gtk_widget_show (label);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK
							 (notebook), 2),
			      label);

  if (viewer_notebook (viewer))
    return 1;

  tips = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (tips);
  gtk_container_add (GTK_CONTAINER (notebook), tips);

  label = gtk_label_new ("Tips");
  gtk_widget_show (label);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK
							 (notebook), 3),
			      label);

  if (tips_notebook (tips))
    return 1;

  gtk_widget_show (editorwin);

  return 0;
}

void
graphic_quit (GtkWidget * w, gpointer dummy)
{
  if (editor_change)
    if (editor_dialog_ask_save ())
      return;

  gtk_main_quit ();
}

/* EOF */
